@@ -64,7 +64,7 @@ see.pois.tck<-function ()
 
 see.poiscdf.tck<-function () 
 {
-  old.par <- par(no.readonly = TRUE)
+#  old.par <- par(no.readonly = TRUE)
     if (!exists("slider.env")) 
         slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
     lambda <- 5
@@ -131,7 +131,7 @@ see.poiscdf.tck<-function ()
         side = "left")
     tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
         side = "right")
-    on.exit(par(old.par))
+  #  on.exit(par(old.par))
     }
 
 
