@@ -65,7 +65,7 @@ tclServiceMode(TRUE)
 
 
 see.weibcdf.tck<-function (){ 
-old.par <- par(no.readonly = TRUE)
+#old.par <- par(no.readonly = TRUE)
 tclServiceMode(TRUE)
     if (!exists("slider.env")) 
         slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
@@ -128,6 +128,6 @@ tclServiceMode(TRUE)
         side = "left")
     tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
         side = "right")
-    on.exit(par(old.par))
+  #  on.exit(par(old.par))
   }  
                             
\ No newline at end of file
